NAME

Text::Similarity - module for measuring the similarity of text documents. This module is a superclass for other modules.

SYNOPSIS

# this will return an un-normalized score that just gives the 
# number of overlaps - this is same synopsis as in Text/Overlaps.pm

use Text::Similarity::Overlaps;
my $mod = Text::Similarity::Overlaps->new;
defined $mod or die "Construction of Text::Similarity::Overlaps failed";

# adjust file names to reflect true relative position
# these paths are valid from lib/Text/
my $text_file1 = '../../t/test1.txt';
my $text_file2 = '../../t/test2.txt';

my $score = $mod->getSimilarity ($text_file1, $text_file2);
print "The similarity of $text_file1 and $text_file2 is : $score\n";

DESCRIPTION

This module serves as a superclass for other modules that implement measures of text document similarity.

SEE ALSO

AUTHOR

Ted Pedersen, University of Minnesota, Duluth tpederse at d.umn.edu

Siddharth Patwardhan sidd at cs.utah.edu

Jason Michelizzi

Last modified by : $Id: Similarity.pm,v 1.10 2008/03/20 01:41:44 tpederse Exp $

COPYRIGHT AND LICENSE

Text::Similarity Copyright (C) 2004-2008, Ted Pdersen, Jason Michelizzi, and Siddharth Patwardhan

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA